==> nuiton-validator-2.6.12-sources.jar: org/nuiton/validator/xwork2/field/NotExistingDirectoryFieldValidator.java <==
/*
 * #%L
 * Nuiton Utils :: Nuiton Validator
 * 
 * $Id: NotExistingDirectoryFieldValidator.java 2182 2011-08-24 13:13:11Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/nuiton-utils/tags/nuiton-utils-2.6.12/nuiton-validator/src/main/java/org/nuiton/validator/xwork2/field/NotExistingDirectoryFieldValidator.java $
 * %%
 * Copyright (C) 2011 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.validator.xwork2.field;

import com.opensymphony.xwork2.validator.ValidationException;

import java.io.File;

/**
 * <!-- START SNIPPET: javadoc -->
 * NotExistingDirectoryFieldValidator checks that a File field as a directory does not exist. *
 * <!-- END SNIPPET: javadoc -->
 * <p/>
 * <p/>
 * <!-- START SNIPPET: parameters -->
 * <ul>
 * <li>fieldName - The field name this validator is validating. Required if using Plain-Validator Syntax otherwise not required</li>
 * </ul>
 * <!-- END SNIPPET: parameters -->
 * <p/>
 * <p/>
 * <pre>
 * <!-- START SNIPPET: examples -->
 *     &lt;validators&gt;
 *         &lt;!-- Plain-Validator Syntax --&gt;
 *         &lt;validator type="notExistingDirectory"&gt;
 *             &lt;param name="fieldName"&gt;tmp&lt;/param&gt;
 *             &lt;message&gt;tmp is an existing directory&lt;/message&gt;
 *         &lt;/validator&gt;
 *
 *         &lt;!-- Field-Validator Syntax --&gt;
 *         &lt;field name="tmp"&gt;
 *         	  &lt;field-validator type="notExistingDirectory"&gt;
 *                 &lt;message&gt;tmp is an existing directory&lt;/message&gt;
 *            &lt;/field-validator&gt;
 *         &lt;/field&gt;
 *     &lt;/validators&gt;
 * <!-- END SNIPPET: examples -->
 * </pre>
 *
 * @author tchemit <chemit@codelutin.com>
 */
public class NotExistingDirectoryFieldValidator extends NuitonFieldValidatorSupport {

    @Override
    public void validateWhenNotSkip(Object object) throws ValidationException {
        String fieldName = getFieldName();
        Object value = getFieldValue(fieldName, object);
        if (value == null) {
            // no value defined
            addFieldError(fieldName, object);
            return;
        }
        File f;
        if (value instanceof File) {
            f = (File) value;
        } else if (value instanceof String) {
            f = new File((String) value);
        } else {
            addFieldError(fieldName, object);
            return;
        }

        if (f.exists() || f.isFile()) {
            addFieldError(fieldName, object);
        }
    }

    @Override
    public String getValidatorType() {
        return "notExistingDirectory";
    }
}

==> nuiton-validator-2.7-sources.jar: org/nuiton/validator/xwork2/field/NotExistingDirectoryFieldValidator.java <==
/*
 * #%L
 * Nuiton Utils :: Nuiton Validator
 * 
 * $Id: NotExistingDirectoryFieldValidator.java 2586 2013-07-20 06:57:12Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/nuiton-utils/tags/nuiton-utils-2.7/nuiton-validator/src/main/java/org/nuiton/validator/xwork2/field/NotExistingDirectoryFieldValidator.java $
 * %%
 * Copyright (C) 2011 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.validator.xwork2.field;

import com.opensymphony.xwork2.validator.ValidationException;

import java.io.File;

/**
 * <!-- START SNIPPET: javadoc -->
 * NotExistingDirectoryFieldValidator checks that a File field as a directory does not exist. *
 * <!-- END SNIPPET: javadoc -->
 * <p/>
 * <p/>
 * <!-- START SNIPPET: parameters -->
 * <ul>
 * <li>fieldName - The field name this validator is validating. Required if using Plain-Validator Syntax otherwise not required</li>
 * </ul>
 * <!-- END SNIPPET: parameters -->
 * <p/>
 * <p/>
 * <pre>
 * <!-- START SNIPPET: examples -->
 *     &lt;validators&gt;
 *         &lt;!-- Plain-Validator Syntax --&gt;
 *         &lt;validator type="notExistingDirectory"&gt;
 *             &lt;param name="fieldName"&gt;tmp&lt;/param&gt;
 *             &lt;message&gt;tmp is an existing directory&lt;/message&gt;
 *         &lt;/validator&gt;
 *
 *         &lt;!-- Field-Validator Syntax --&gt;
 *         &lt;field name="tmp"&gt;
 *         	  &lt;field-validator type="notExistingDirectory"&gt;
 *                 &lt;message&gt;tmp is an existing directory&lt;/message&gt;
 *            &lt;/field-validator&gt;
 *         &lt;/field&gt;
 *     &lt;/validators&gt;
 * <!-- END SNIPPET: examples -->
 * </pre>
 *
 * @author tchemit <chemit@codelutin.com>
 * @deprecated since 2.7, use now the http://maven-site.nuiton.org/nuiton-validator project, This module will be remove in version 3.0
 */
@Deprecated
public class NotExistingDirectoryFieldValidator extends NuitonFieldValidatorSupport {

    @Override
    public void validateWhenNotSkip(Object object) throws ValidationException {
        String fieldName = getFieldName();
        Object value = getFieldValue(fieldName, object);
        if (value == null) {
            // no value defined
            addFieldError(fieldName, object);
            return;
        }
        File f;
        if (value instanceof File) {
            f = (File) value;
        } else if (value instanceof String) {
            f = new File((String) value);
        } else {
            addFieldError(fieldName, object);
            return;
        }

        if (f.exists() || f.isFile()) {
            addFieldError(fieldName, object);
        }
    }

    @Override
    public String getValidatorType() {
        return "notExistingDirectory";
    }
}
